<?php

namespace CreoCode\ContaoPopup\Classes;

use Contao\Frontend;
use Contao\PageModel;
use Contao\FrontendTemplate;
use Contao\ContentModel;

use CreoCode\ContaoPopup\Models\PopupModel;
use CreoCode\ContaoPopup\Models\PopupSetModel;

/**
 * Extension version
 */
class GeneratePage extends Frontend
{

	/**
	 * Check whether a popup is enabled and should be displayed
	 *
	 * @param \PageModel $rootPage
	 *
	 * @return boolean
	 */
	protected function isPopupEnabled(\PageModel $rootPage = null)
	{
		global $objPage;
		
		$objRoot = PageModel::findByPk($objPage->rootId);
		$popupSet = $objRoot->popup_set;

		if ($popupSet) {
			$popups = PopupModel::findPublishedByPid($popupSet);

			if (!$popups) {
				return false;
			}
			
			$popupArray = array();
			foreach ($popups as $popup) {
				if ($popup->pages) {
					$pages = unserialize($popup->pages);
					if (in_array($objPage->id, $pages)) {
						array_push($popupArray, $popup);
					}
				} else {
					array_push($popupArray, $popup);
				}
			}
			return $popupArray;
		}
		return false;
	}


	/**
	 * Add the cookie HTML buffer
	 * @param string
	 * @return string
	 */
	public function addPopups($strBuffer, $strTemplate)
	{		
        if(empty($strBuffer)) {
            return $strBuffer;
        }

		$popup = $this->isPopupEnabled();
		if ($popup) {

			foreach ($popup as $popup) {
				$objTemplate = new FrontendTemplate($popup->template);
				$objTemplate->id = "popup-".$popup->id;
				$objTemplate->customId = "popup-".$popup->customId;
				$objTemplate->class = "popup";
				if ($popup->cssClass) {
					$objTemplate->class = "popup ".$popup->cssClass;
				}
				//Position settings
				$objTemplate->position = $popup->position;
				//Appearance settings
				$objTemplate->appearance = $popup->appearance;
				$objTemplate->delay = $popup->delay;
				$objTemplate->scrollOffset = $popup->scrollOffset;
				$objTemplate->cookieExpire = $popup->cookieExpire;

				// Add content to popup
				$objTemplate->text = '';
				$objTemplate->hasText = false;

				$id = $popup->id;
				$objTemplate->text = function () use ($id) {
					$strText = '';
					$objElement = ContentModel::findPublishedByPidAndTable($id, 'tl_popup');

					if ($objElement !== null)
					{
						while ($objElement->next())
						{
							$strText .= $this->getContentElement($objElement->current());
						}
					}

					return $strText;
				};
				$objTemplate->hasText = function () use ($popup) {
					return ContentModel::countPublishedByPidAndTable($popup->id, 'tl_popup') > 0;
				};

				//$strBuffer = $strBuffer . $objTemplate->parse();
				//$strBuffer = str_replace('</body>', $objTemplate->parse() . '</body>', $strBuffer);
				$strBuffer = $this->str_replace_last('</body>', $objTemplate->parse() . '</body>', $strBuffer);

			}

		}
		
		return $strBuffer;
	}

	/**
	 * Str replace last
	 */
	function str_replace_last($search, $replace, $subject) {
	    $pos = strrpos($subject, $search);

	    if($pos !== false)
	    {
	        $subject = substr_replace($subject, $replace, $pos, strlen($search));
	    }

	    return $subject;
	}
}